@@ -7,9 +7,9 @@
 
 #pragma once
 
-#include <QObject>
 #include <QDateTime>
 #include <QJsonObject>
+#include <QObject>
 
 class Recording : public QObject
 {
@@ -19,20 +19,24 @@ class Recording : public QObject
     Q_PROPERTY(QString fileName READ fileName WRITE setFileName NOTIFY propertyChanged)
     Q_PROPERTY(QString recordDate READ recordDatePretty NOTIFY propertyChanged)
     Q_PROPERTY(QString recordingLength READ recordingLengthPretty NOTIFY propertyChanged)
-    
+
 public:
-    explicit Recording(QObject *parent = nullptr, const QString &filePath = {}, const QString &fileName = {}, QDateTime recordDate = QDateTime::currentDateTime(), int recordingLength = 0);
+    explicit Recording(QObject *parent = nullptr,
+                       const QString &filePath = {},
+                       const QString &fileName = {},
+                       QDateTime recordDate = QDateTime::currentDateTime(),
+                       int recordingLength = 0);
     explicit Recording(QObject *parent, const QJsonObject &obj);
-    
+
     QJsonObject toJson() const;
-    
+
     QString filePath() const;
     QString fileName() const;
     QString fileExtension() const;
-    
+
     QDateTime recordDate() const;
     QString recordDatePretty() const;
-    
+
     int recordingLength() const;
     QString recordingLengthPretty() const;
 
@@ -41,7 +45,7 @@ public:
 
     void setRecordDate(const QDateTime &date);
     void setRecordingLength(int recordingLength);
-    
+
     Q_INVOKABLE void createCopyOfFile(const QString &path);
 
 private:
